package kaysaar.aotd_question_of_loyalty.data.misc;

import com.fs.starfarer.api.campaign.CargoStackAPI;
import com.fs.starfarer.api.campaign.CargoAPI;
import java.util.Iterator;
import com.fs.starfarer.api.campaign.CampaignFleetAPI;
import com.fs.starfarer.api.campaign.SectorEntityToken;
import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.campaign.EngagementResultForFleetAPI;
import com.fs.starfarer.api.combat.EngagementResultAPI;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;
import com.fs.starfarer.api.util.Misc;

public class QoLMisc
{
    public static boolean isStringValid(final String forCheck, final String checkingFor) {
        if (checkingFor == null) {
            return isStringValid(forCheck);
        }
        return isStringValid(forCheck) && forCheck.equals(checkingFor);
    }
    
    public static boolean isStringValid(final String forCheck) {
        return forCheck != null && !forCheck.isEmpty();
    }
    
    public static boolean isCommissionedBy(final String factionID) {
        return isStringValid(Misc.getCommissionFactionId(), factionID);
    }
    
    public static Set<String> loadEntriesSet(final String rawMap, final String seperator) {
        if (!isStringValid(rawMap)) {
            return new HashSet<String>();
        }
        final String[] splitted = rawMap.split(seperator);
        return new HashSet<String>(Arrays.asList(splitted));
    }
    
    public static ArrayList<String> loadEntriesArray(final String rawMap, final String seperator) {
        if (!isStringValid(rawMap)) {
            return new ArrayList<String>();
        }
        final String[] splitted = rawMap.split(seperator);
        return new ArrayList<String>(Arrays.asList(splitted));
    }
    
    public static EngagementResultForFleetAPI getNonPlayerFleet(final EngagementResultAPI resultAPI) {
        if (!resultAPI.getLoserResult().isPlayer()) {
            return resultAPI.getLoserResult();
        }
        return resultAPI.getWinnerResult();
    }
    
    public static boolean isInSpaceofCommisionedFaction() {
        if (!isCommissioned()) {
            return false;
        }
        if (Global.getSector().getPlayerFleet().getStarSystem() == null) {
            return false;
        }
        if (Global.getSector().getPlayerFleet().getStarSystem().isHyperspace()) {
            return false;
        }
        for (final SectorEntityToken allEntity : Global.getSector().getPlayerFleet().getStarSystem().getAllEntities()) {
            if (allEntity instanceof CampaignFleetAPI) {
                continue;
            }
            if (allEntity.getMarket() != null && allEntity.getMarket().getFactionId() != null && isCommissionedBy(allEntity.getMarket().getFactionId())) {
                return true;
            }
        }
        return false;
    }
    
    public static int getFreeSpaceAvailable(final CargoAPI cargo) {
        int total = (int)cargo.getMaxCapacity();
        for (final CargoStackAPI cargoStackAPI : cargo.getStacksCopy()) {
            total -= (int)cargoStackAPI.getCargoSpace();
        }
        return total;
    }
    
    public static boolean isCommissioned() {
        return isStringValid(Misc.getCommissionFactionId(), null);
    }
}
